@@ -1,9 +1,10 @@
+## no critic: TestingAndDebugging::RequireUseStrict
 package Log::ger::Manual;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-07'; # DATE
+our $DATE = '2022-06-10'; # DATE
 our $DIST = 'Log-ger-Manual'; # DIST
-our $VERSION = '0.033.000'; # VERSION
+our $VERSION = '0.040.000'; # VERSION
 
 1;
 # ABSTRACT: Manual for Log::ger
@@ -20,7 +21,7 @@ Log::ger::Manual - Manual for Log::ger
 
 =head1 VERSION
 
-version 0.033.000
+version 0.040.000
 
 =head1 DESCRIPTION
 
@@ -104,7 +105,13 @@ This distribution contains the following documentation pages:
 
 =back
 
-Start with L<Log::ger::Manual::Tutorial>.
+If you want to use Log::ger in your module and applications, start with
+L<Log::ger::Manual::Tutorial>.
+
+If you want to understand the concept and the code, or want to write a plugin,
+start with the glossary in L<Log::ger::Manual::Internals>.
+
+For various logging issues, start with L<Log::ger::Manual::FAQ>.
 
 =head1 AUTHOR
 
@@ -112,7 +119,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019, 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020, 2019, 2018, 2017 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
